.. _changelog:

Changelog
=========

.. _unreleased:

Unreleased
----------

Added
~~~~~
- Initial release of NagaNLP
- POS tagging with Transformer models
- Neural Machine Translation
- Subword tokenization
- NLTK-based POS tagger

Changed
~~~~~~~
- Switched examples to use Romanized Nagamese text

Fixed
~~~~~
- Fixed tensor shape handling in Translator
- Improved test coverage

0.1.0 (2025-08-02)
------------------

First public release.
